==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/zh_CN.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "存储临时性不可用",
    "Storage invalid" : "存储空间无效",
    "Unknown error" : "未知错误",
    "All files" : "全部文件",
    "Saved" : "已保存",
    "There was an error saving" : "保存错误",
    "File could not be found" : "文件未找到",
    "Home" : "家庭",
    "Close" : "关闭",
    "Favorites" : "收藏",
    "Could not create folder \"{dir}\"" : "不能创建文件夹 \"{dir}\"",
    "Upload cancelled." : "上传已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "不能上传文件 {filename} ，由于它是一个目录或者为0字节",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "没有足够的可用空间，您正在上传 {size1} 的文件但是只有 {size2} 可用。",
    "Target folder \"{dir}\" does not exist any more" : "目标目录“{dir}”不存在",
    "Not enough free space" : "空闲空间不足",
    "Uploading..." : "上传中...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "文件正在上传中。现在离开此页会导致上传动作被取消。",
    "Actions" : "动作",
    "Download" : "下载",
    "Rename" : "重命名",
    "Delete" : "删除",
    "Disconnect storage" : "断开储存连接",
    "Unshare" : "取消共享",
    "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
    "Files" : "文件",
    "Details" : "详细信息",
    "Select" : "选择",
    "Pending" : "等待",
    "Unable to determine date" : "无法确定日期",
    "Invalid path" : "无效路径",
    "This operation is forbidden" : "操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
    "Could not move \"{file}\", target exists" : "不能移动 \"{file}\"，目标已存在。",
    "Could not move \"{file}\"" : "不能移动 \"{file}\"",
    "{newName} already exists" : "{newname} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "不能重命名 \"{fileName}\"，此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "在文件夹 \"{dir}\" 中已经存在 \"{targetName}\" 。请换一个名字试下。",
    "Could not rename \"{fileName}\"" : "不能重命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "不能创建文件 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "不能创建文件 \"{file}\" ，因为它已经存在",
    "Could not create folder \"{dir}\" because it already exists" : "不能创建文件夹 \"{dir}\" ，因为它已经存在",
    "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错。",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "_%n folder_::_%n folders_" : ["%n 文件夹"],
    "_%n file_::_%n files_" : ["%n个文件"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包含 %n 隐藏项"],
    "You don’t have permission to upload or create files here" : "您在这没有上传和创建文件的权限",
    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
    "New" : "新建",
    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" 的文件类型/扩展名被禁止。",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["匹配“{filter}”"],
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Favorite" : "收藏",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "私人链接：只有有权访问该文件/文件夹的人才可以使用它。将其作为给您自己或者其他人分享文件的永久链接。",
    "Folder" : "文件夹",
    "New folder" : "增加文件夹",
    "{newname} already exists" : "{newname} 已经存在",
    "Upload" : "上传",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "A new file or folder has been <strong>created</strong>" : "一个新的文件或文件夹已被<strong>创建</strong>",
    "A file or folder has been <strong>changed</strong>" : "一个文件或文件夹已被<strong>修改</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "针对<strong>已收藏文件</strong>的新建和修改发送有限的通知 <em>(仅流)</em>",
    "A file or folder has been <strong>deleted</strong>" : "一个文件或文件夹已被<strong>删除</strong>",
    "A file or folder has been <strong>restored</strong>" : "一个文件或文件夹已经被 <strong>恢复</strong>",
    "You created %1$s" : "您创建了%1$s",
    "%2$s created %1$s" : "%2$s 创建了 %1$s",
    "%1$s was created in a public folder" : "%1$s 被创建在公开文件夹中",
    "You changed %1$s" : "您修改了%1$s",
    "%2$s changed %1$s" : "%2$s 修改了 %1$s",
    "You deleted %1$s" : "您删除了 %1$s",
    "%2$s deleted %1$s" : "%2$s 删除了 %1$s",
    "You restored %1$s" : "你恢复了 %1$s",
    "%2$s restored %1$s" : "%2$s 恢复了 %1$s",
    "Changed by %2$s" : "被 %2$s 更改",
    "Deleted by %2$s" : "被 %2$s 删除",
    "Restored by %2$s" : "被 %2$s 恢复",
    "Upload (max. %s)" : "上传 (最大 %s)",
    "File handling" : "文件处理",
    "Maximum upload size" : "最大上传大小",
    "max. possible: " : "最大允许: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效。",
    "Missing permissions to edit from here." : "没有从这里进行编辑的权限",
    "Settings" : "设置",
    "Show hidden files" : "显示隐藏文件",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">通过 WebDAV 访问您的文件</a>",
    "No files in here" : "无文件",
    "Upload some content or sync with your devices!" : "上传一些内容或者与设备同步!",
    "No entries found in this folder" : "此文件夹中无项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您正尝试上传的文件超过了此服务器可以上传的最大容量限制",
    "No favorites" : "无收藏",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "Text file" : "文本文件",
    "New text file.txt" : "创建文本文件 .txt"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/zh_CN.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "存储临时性不可用",
    "Storage invalid" : "存储空间无效",
    "Unknown error" : "未知错误",
    "All files" : "全部文件",
    "Saved" : "已保存",
    "There was an error saving" : "保存错误",
    "File could not be found" : "文件未找到",
    "Home" : "家庭",
    "Close" : "关闭",
    "Favorites" : "收藏",
    "Could not create folder \"{dir}\"" : "不能创建文件夹 \"{dir}\"",
    "Upload cancelled." : "上传已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "不能上传文件 {filename} ，由于它是一个目录或者为0字节",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "没有足够的可用空间，您正在上传 {size1} 的文件但是只有 {size2} 可用。",
    "Target folder \"{dir}\" does not exist any more" : "目标目录“{dir}”不存在",
    "Not enough free space" : "空闲空间不足",
    "Uploading..." : "上传中...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "文件正在上传中。现在离开此页会导致上传动作被取消。",
    "Actions" : "动作",
    "Download" : "下载",
    "Rename" : "重命名",
    "Delete" : "删除",
    "Disconnect storage" : "断开储存连接",
    "Unshare" : "取消共享",
    "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
    "Files" : "文件",
    "Details" : "详细信息",
    "Select" : "选择",
    "Pending" : "等待",
    "Unable to determine date" : "无法确定日期",
    "Invalid path" : "无效路径",
    "This operation is forbidden" : "操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
    "Could not move \"{file}\", target exists" : "不能移动 \"{file}\"，目标已存在。",
    "Could not move \"{file}\"" : "不能移动 \"{file}\"",
    "{newName} already exists" : "{newname} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "不能重命名 \"{fileName}\"，此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "在文件夹 \"{dir}\" 中已经存在 \"{targetName}\" 。请换一个名字试下。",
    "Could not rename \"{fileName}\"" : "不能重命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "不能创建文件 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "不能创建文件 \"{file}\" ，因为它已经存在",
    "Could not create folder \"{dir}\" because it already exists" : "不能创建文件夹 \"{dir}\" ，因为它已经存在",
    "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错。",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "_%n folder_::_%n folders_" : ["%n 文件夹"],
    "_%n file_::_%n files_" : ["%n个文件"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包含 %n 隐藏项"],
    "You don’t have permission to upload or create files here" : "您在这没有上传和创建文件的权限",
    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
    "New" : "新建",
    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" 的文件类型/扩展名被禁止。",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["匹配“{filter}”"],
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Favorite" : "收藏",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "私人链接：只有有权访问该文件/文件夹的人才可以使用它。将其作为给您自己或者其他人分享文件的永久链接。",
    "Folder" : "文件夹",
    "New folder" : "增加文件夹",
    "{newname} already exists" : "{newname} 已经存在",
    "Upload" : "上传",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "A new file or folder has been <strong>created</strong>" : "一个新的文件或文件夹已被<strong>创建</strong>",
    "A file or folder has been <strong>changed</strong>" : "一个文件或文件夹已被<strong>修改</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "针对<strong>已收藏文件</strong>的新建和修改发送有限的通知 <em>(仅流)</em>",
    "A file or folder has been <strong>deleted</strong>" : "一个文件或文件夹已被<strong>删除</strong>",
    "A file or folder has been <strong>restored</strong>" : "一个文件或文件夹已经被 <strong>恢复</strong>",
    "You created %1$s" : "您创建了%1$s",
    "%2$s created %1$s" : "%2$s 创建了 %1$s",
    "%1$s was created in a public folder" : "%1$s 被创建在公开文件夹中",
    "You changed %1$s" : "您修改了%1$s",
    "%2$s changed %1$s" : "%2$s 修改了 %1$s",
    "You deleted %1$s" : "您删除了 %1$s",
    "%2$s deleted %1$s" : "%2$s 删除了 %1$s",
    "You restored %1$s" : "你恢复了 %1$s",
    "%2$s restored %1$s" : "%2$s 恢复了 %1$s",
    "Changed by %2$s" : "被 %2$s 更改",
    "Deleted by %2$s" : "被 %2$s 删除",
    "Restored by %2$s" : "被 %2$s 恢复",
    "Upload (max. %s)" : "上传 (最大 %s)",
    "File handling" : "文件处理",
    "Maximum upload size" : "最大上传大小",
    "max. possible: " : "最大允许: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效。",
    "Missing permissions to edit from here." : "没有从这里进行编辑的权限",
    "Settings" : "设置",
    "Show hidden files" : "显示隐藏文件",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">通过 WebDAV 访问您的文件</a>",
    "No files in here" : "无文件",
    "Upload some content or sync with your devices!" : "上传一些内容或者与设备同步!",
    "No entries found in this folder" : "此文件夹中无项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您正尝试上传的文件超过了此服务器可以上传的最大容量限制",
    "No favorites" : "无收藏",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "Text file" : "文本文件",
    "New text file.txt" : "创建文本文件 .txt",
    "Target folder does not exist any more" : "目标文件夹已不存在",
    "Upload timeout for file \"{file}\"" : "上传文件 {file} 超时",
    "Processing files..." : "处理文件中...",
    "No entries in this folder match {filter}" : "此文件夹中无项目匹配 {filter}",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "限制关于<strong>已收藏文件</strong>的新建和修改相关的通知",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "你无权访问此文件/目录 - 请联系拥有者向你分享此权限。",
    "Error when assembling chunks, status code {status}" : "合并文件块时发生 {status} 代码错误"
},
"nplurals=1; plural=0;");
